@@ -1,3 +1,6 @@
+#!/bin/sh
+set -ev
+
 # This is how the Mac binaries for release are built, so I don't forget!
 # Any existing mac-build and teckit-mac/{bin,lib} directories will be deleted.
 # then go to mac-installer/ and run ./create-pkg.sh to generate the pkg and dmg.
@@ -9,6 +12,7 @@ cd mac-build
 
 ../configure --enable-final --disable-dependency-tracking
 make
+(make check || cat test/dotests.pl.log)
 make install DESTDIR=`pwd`/inst
 
 cd ..
