@@ -1,4 +1,5 @@
 #!/bin/sh
+set -ev
 
 # This is how the Windows binaries for release are built, so I don't forget!
 
@@ -9,6 +10,8 @@ PATH=/usr/local/mingw/bin:$PATH
 
 rm -rf $WINDOWS
 
+file /usr/bin/i686-w64-mingw32-ld /usr/bin/x86_64-w64-mingw32-ld
+
 for bit in 32 64
 do
     WINDOWS_BUILD=windows-build${bit}
@@ -19,6 +22,7 @@ do
     BUILD=$(../config.guess)
     set_compiler $bit
 
+    echo "BUILD=${BUILD} HOST=${HOST} bit=${bit}"
     ../configure --build=$BUILD --host=$HOST --with-old-lib-names --without-system-zlib --enable-final --disable-dependency-tracking
     make
     make install-strip DESTDIR=`pwd`/inst
